function [classes, cert] = bayes_class_2d(x, p1, m1, K1, p2, m2, K2)
//-----------------------------------------------------------------------  
//function [classes, cert] = bayes_class_2d(x, p1, m1, K1, p2, m2, K2)
//
// implementation of bayes classification of two-dimensional 
// vectors in case of a two-class problem with class conditional
// probability distributions assumed to be normal distributions
// definined by the statistical parameters p1,m1,K1,p2,m2,K2. 
//
// input:    x            2 times n - real matrix consisting of n
//                        points to be classified
//           p1, p2       prior probabilities of the two classes (sum == 1)
//           m1, m2       mean vectors of the two classes
//           K1, K2       covariance matrices of the two distributions
//
// output:   classes      n-vector of estimated class memberships (1 or 2) 
//           cert         n-vector of certainty measures for the 
//                        classifications, in this case P(w_cl | x)
//
//-----------------------------------------------------------------------  
//   $RCSfile: bayes_class_2d.sci,v $
//  $Revision: 1.1 $
//      $Date: 2002/09/10 15:15:36 $
//  Copyright: IIF-LMB $Author: poluru $
//
//-----------------------------------------------------------------------
//  $Log: bayes_class_2d.sci,v $
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  [out,in] = argn(0);

  if in~=7 
    if in~=1 
      error('wrong number of input arguments.');
    end;
    
    //setting the default values, if p,m,k are not given
    // DATA is the absolute path to the data directory    
    global DATA;
    exec(DATA+'data.sci');
    p1=0.5;
    p2=0.5;
  end;
  
  nsamples = size(x,2);
  
  // calculation of class-conditional probabilities:
  // p(x|w_i) = 1/(2*pi*sqrt(det(K_i))) 
  //            * exp (-0.5*(x-m_i)' * inv(K_i) * (x-m_i)) 
  // first 'repeat' vectors m_i
  
  M1 = [m1(1)*ones(1,nsamples); m1(2)*ones(1,nsamples)];
  M2 = [m2(1)*ones(1,nsamples); m2(2)*ones(1,nsamples)];
  
  // exponents of ccp:
  e1 = -0.5 * sum(((x-M1)' * inv(K1))' .* (x-M1),'r');
  e2 = -0.5 * sum(((x-M2)' * inv(K2))' .* (x-M2),'r');
  
  ccp1 = 1/(2*%pi*sqrt(det(K1))) * exp(e1);
  ccp2 = 1/(2*%pi*sqrt(det(K2))) * exp(e2);
  
  // calculate values for MAP decision:
  d1 = p1 * ccp1;
  d2 = p2 * ccp2;
  
  // MAP decision and generation of class labels
  classes = (d1 < d2) + 1;
  maxp = max(d1,d2);
  
  // a-posteriori probabilities (certainty)
  cert = maxp ./ (d1+d2);
  
endfunction







